@@ -1,6 +1,7 @@
 use byteorder::{ByteOrder, NetworkEndian, WriteBytesExt};
 use log::{debug, log_enabled, trace};
 use std::io::{Read, Write};
+#[cfg(target_family = "unix")]
 use std::os::unix::net::UnixStream;
 use std::{net::TcpStream, time::Instant};
 
@@ -19,8 +20,9 @@ fn write_segment(
 
     if log_enabled!(log::Level::Trace) {
         trace!(
-            "sending segment, header {:?}, payload length: {}",
+            "sending segment, header {:?}, protocol id: {}, payload length: {}",
             hex::encode(&msg),
+            protocol_id,
             payload.len()
         );
     }
@@ -61,7 +63,7 @@ fn read_segment(reader: &mut impl Read) -> Result<(u16, u32, Payload), std::io::
 
 impl Bearer for TcpStream {
     fn clone(&self) -> Self {
-        self.try_clone().unwrap()
+        self.try_clone().expect("error cloning tcp stream")
     }
 
     fn read_segment(&mut self) -> Result<(u16, u32, Payload), std::io::Error> {
@@ -78,9 +80,10 @@ impl Bearer for TcpStream {
     }
 }
 
+#[cfg(target_family = "unix")]
 impl Bearer for UnixStream {
     fn clone(&self) -> Self {
-        self.try_clone().unwrap()
+        self.try_clone().expect("error cloning unix stream")
     }
 
     fn read_segment(&mut self) -> Result<(u16, u32, Payload), std::io::Error> {
